Spherical harmonic model of the magnetic field of Mars from Langlais et al. (2019)
- "Martian magnetic field model, based on 14386 ESD, inversion using MGS MAG, MGS ER and MAVEN MAG, field predicted at 150km altitude. SH model, ref surface = 3393.5 km"
- Langlais, B., Thébault, E., Houliez, A., Purucker, M.E., Lillis, R.J. (2019). A new model of the crustal magnetic field of Mars using MGS and MAVEN. Journal of Geophysical Research: Planets, 124, 1542-1569, doi:10.1029/2018JE005854.

Links:
- Download: https://doi.org/10.5281/zenodo.3876714
- Paper: https://doi.org/10.1029/2018JE005854
- Source code for loading: https://github.com/SHTOOLS/SHTOOLS/blob/master/pyshtools/datasets/Mars/__init__.py
